From yani.ioannou@gmail.com Tue May 17 03:40:04 2005
Message-ID: <253818670505170339187ebecd@mail.gmail.com>
Date: Tue, 17 May 2005 06:39:34 -0400
From: Yani Ioannou <yani.ioannou@gmail.com>
To: Greg KH <greg@kroah.com>
Subject: Driver core: change device_attribute callbacks

This patch adds the device_attribute paramerter to the
device_attribute store and show sysfs callback functions, and passes a
reference to the attribute when the callbacks are called.

Signed-off-by: Yani Ioannou <yani.ioannou@gmail.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>

---
 drivers/base/core.c    |    4 ++--
 include/linux/device.h |    6 ++++--
 2 files changed, 6 insertions(+), 4 deletions(-)

--- gregkh-2.6.orig/drivers/base/core.c	2005-05-17 22:48:39.000000000 -0700
+++ gregkh-2.6/drivers/base/core.c	2005-05-17 23:07:05.000000000 -0700
@@ -39,7 +39,7 @@
 	ssize_t ret = -EIO;
 
 	if (dev_attr->show)
-		ret = dev_attr->show(dev, buf);
+		ret = dev_attr->show(dev, dev_attr, buf);
 	return ret;
 }
 
@@ -52,7 +52,7 @@
 	ssize_t ret = -EIO;
 
 	if (dev_attr->store)
-		ret = dev_attr->store(dev, buf, count);
+		ret = dev_attr->store(dev, dev_attr, buf, count);
 	return ret;
 }
 
--- gregkh-2.6.orig/include/linux/device.h	2005-05-17 22:48:39.000000000 -0700
+++ gregkh-2.6/include/linux/device.h	2005-05-17 23:09:14.000000000 -0700
@@ -335,8 +335,10 @@
 
 struct device_attribute {
 	struct attribute	attr;
-	ssize_t (*show)(struct device * dev, char * buf);
-	ssize_t (*store)(struct device * dev, const char * buf, size_t count);
+	ssize_t (*show)(struct device *dev, struct device_attribute *attr,
+			char *buf);
+	ssize_t (*store)(struct device *dev, struct device_attribute *attr,
+			 const char *buf, size_t count);
 };
 
 #define DEVICE_ATTR(_name,_mode,_show,_store) \
